@@ -58,11 +58,14 @@
 #' the variables in each bootstrap
 #' sample.
 #'
-#' @param fit Either (a) a list of `lm`
+#' @param fit It can be (a) a list of `lm`
 #' class objects, or the output of
 #' [lm2list()] (i.e., an `lm_list`-class
 #' object), or (b) the output of
 #' [lavaan::sem()].
+#' If it is a single model fitted by
+#' [lm()], it will be automatically converted
+#' to a list by [lm2list()].
 #'
 #' @param R The number of bootstrap
 #' samples. Default is 100.
@@ -71,6 +74,13 @@
 #' bootstrapping. Default is `NULL` and
 #' seed is not set.
 #'
+#' @param compute_implied_stats If
+#' `TRUE`, default, implied statistics
+#' will be computed for each bootstrap
+#' sample. Letting users to disable this
+#' is an experimental features to let
+#' the process run faster.
+#'
 #' @param parallel Logical. Whether
 #' parallel processing will be used.
 #' Default is `TRUE`.
@@ -136,7 +146,11 @@ do_boot <- function(fit,
                     parallel = TRUE,
                     ncores = max(parallel::detectCores(logical = FALSE) - 1, 1),
                     make_cluster_args = list(),
-                    progress = TRUE) {
+                    progress = TRUE,
+                    compute_implied_stats = TRUE) {
+    if (!missing(fit)) {
+         fit <- auto_lm2list(fit)
+      }
     fit_type <- cond_indirect_check_fit(fit)
     if (fit_type == "lavaan.mi") {
         stop("Bootstrapping does not support multiple imputation.")
@@ -155,6 +169,7 @@ do_boot <- function(fit,
             out <- fit2boot_out_do_boot(fit = fit,
                                         R = R,
                                         seed = seed,
+                                        compute_implied_stats = compute_implied_stats,
                                         parallel = parallel,
                                         ncores = ncores,
                                         make_cluster_args = make_cluster_args,
@@ -166,6 +181,7 @@ do_boot <- function(fit,
             out <- lm2boot_out_parallel(outputs = fit,
                                         R = R,
                                         seed = seed,
+                                        compute_implied_stats = compute_implied_stats,
                                         parallel = parallel,
                                         ncores = ncores,
                                         make_cluster_args = make_cluster_args,
@@ -174,6 +190,7 @@ do_boot <- function(fit,
             out <- lm2boot_out(outputs = fit,
                               R = R,
                               seed = seed,
+                              compute_implied_stats = compute_implied_stats,
                               progress = progress)
           }
       }
