@@ -1,3 +1,5 @@
+skip_on_cran()
+# This test is long and should be tested locally.
 library(testthat)
 library(manymome)
 suppressMessages(library(lavaan))
@@ -49,18 +51,30 @@ indmomo := d1 * d2 * b2
 fitmomo2 <- sem(modmomo2, dat, meanstructure = TRUE, fixed.x = FALSE)
 fitmomo2_boot_out <- do_boot(fitmomo2, R = 40, seed = 1234, parallel = FALSE, progress = FALSE)
 
-set.seed(1234)
-fitmo1_boot <- sem(modmo1, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
-                warn = FALSE)
-set.seed(1234)
-fitmo2_boot <- sem(modmo2, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
-                warn = FALSE)
-set.seed(1234)
-fitmomo1_boot <- sem(modmomo1, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
-                warn = FALSE)
-set.seed(1234)
-fitmomo2_boot <- sem(modmomo2, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
-                warn = FALSE)
+# Adapt to a change in lavaan 0.6-13
+if (packageVersion("lavaan") > "0.6.12") {
+    fitmo1_boot <- sem(modmo1, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
+                    warn = FALSE, iseed = 1234)
+    fitmo2_boot <- sem(modmo2, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
+                    warn = FALSE, iseed = 1234)
+    fitmomo1_boot <- sem(modmomo1, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
+                    warn = FALSE, iseed = 1234)
+    fitmomo2_boot <- sem(modmomo2, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
+                    warn = FALSE, iseed = 1234)
+  } else {
+    set.seed(1234)
+    fitmo1_boot <- sem(modmo1, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
+                    warn = FALSE)
+    set.seed(1234)
+    fitmo2_boot <- sem(modmo2, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
+                    warn = FALSE)
+    set.seed(1234)
+    fitmomo1_boot <- sem(modmomo1, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
+                    warn = FALSE)
+    set.seed(1234)
+    fitmomo2_boot <- sem(modmomo2, dat, meanstructure = TRUE, fixed.x = FALSE, se = "boot", bootstrap = 40,
+                    warn = FALSE)
+  }
 
 ind_mome1 <- index_of_mome(x = "x", y = "y", m = c("m1", "m2"), w = "w1",
                            fit = fitmo1, boot_ci = TRUE, boot_out = fitmo1_boot_out)
@@ -71,21 +85,21 @@ ind_momome1 <- index_of_momome(x = "x", y = "y", m = c("m1", "m2"), w = "w1", z
 ind_momome2 <- index_of_momome(x = "x", y = "y", m = c("m1", "m2"), w = "w1", z = "w2",
                            fit = fitmomo2, boot_ci = TRUE, boot_out = fitmomo2_boot_out)
 
-coef(ind_mome1)
-confint(ind_mome1)
-print(parameterEstimates(fitmo1_boot)[22, c("est", "ci.lower", "ci.upper")], nd = 8)
+# coef(ind_mome1)
+# confint(ind_mome1)
+# print(parameterEstimates(fitmo1_boot)[22, c("est", "ci.lower", "ci.upper")], nd = 8)
 
-coef(ind_mome2)
-confint(ind_mome2)
-print(parameterEstimates(fitmo2_boot)[22, c("est", "ci.lower", "ci.upper")], nd = 8)
+# coef(ind_mome2)
+# confint(ind_mome2)
+# print(parameterEstimates(fitmo2_boot)[22, c("est", "ci.lower", "ci.upper")], nd = 8)
 
-coef(ind_momome1)
-confint(ind_momome1)
-print(parameterEstimates(fitmomo1_boot)[35, c("est", "ci.lower", "ci.upper")], nd = 8)
+# coef(ind_momome1)
+# confint(ind_momome1)
+# print(parameterEstimates(fitmomo1_boot)[35, c("est", "ci.lower", "ci.upper")], nd = 8)
 
-coef(ind_momome2)
-confint(ind_momome2)
-print(parameterEstimates(fitmomo2_boot)[35, c("est", "ci.lower", "ci.upper")], nd = 8)
+# coef(ind_momome2)
+# confint(ind_momome2)
+# print(parameterEstimates(fitmomo2_boot)[35, c("est", "ci.lower", "ci.upper")], nd = 8)
 
 
 test_that("index_of_mome and index_of_momome", {
