@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not_installed("semTools")
+skip_if_not_installed("lavaan.mi")
 
 library(testthat)
 library(manymome)
